/*
 * Ayttm 
 *
 * Copyright (C) 2003, the Ayttm team
 * 
 * Ayttm is derivative of Everybuddy
 * Copyright (C) 1999-2002, Torrey Searle <tsearle@uci.edu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

/*
 * contact.h
 * for keeping track of contacts
 */

#ifndef __CONTACT_H__
#define __CONTACT_H__

#include "account.h"
#include "trigger.h"
#include "logs.h"

struct contact {
	char nick[255];
	char language[3];
	char gpg_key[48];
	int gpg_do_encryption;
	int gpg_do_signature;
	trigger_struct trigger;
	LList *accounts;
	int expanded;
	int online;
	int send_offline;
	int default_chatb;
	int default_filetransb;
	struct _grouplist *group;
	struct _chat_window *chatwindow;
	t_log_window_id logwindow;

	void *list_item;	/* GtkWidget */
	void *tree;		/* GtkWidget */
	void *pix;		/* GtkWidget */
	void *status;		/* GtkWidget */
	void *label;		/* GtkWidget */
	int icon_handler;
};

#endif
